Learn R Programming

readODS (version 1.7.0)

get_num_sheets_in_ods: get the number of sheets in an ods file

Description

get the number of sheets in an ods file

Usage

get_num_sheets_in_ods(path)

getNrOfSheetsInODS(path)

Value

Number of sheets

Arguments

path

path to the ods file

Author

Chung-hong Chan [email protected], Gerrit-Jan Schutten [email protected]

See Also

use read_ods to read the data